==> orchestra-axis-4.0.11-sources.jar: org/ow2/orchestra/axis/AxisEnvXmlGenerator.java <==
package org.ow2.orchestra.axis;

import java.io.File;
import java.io.IOException;

import org.ow2.orchestra.env.DefaultEnvXMLGenerator;
import org.ow2.orchestra.facade.exception.OrchestraRuntimeException;
import org.ow2.orchestra.services.handlers.impl.ArchiveFinishedInstanceHandler;
import org.ow2.orchestra.services.handlers.impl.ArchiveUndeployedProcessHandler;
import org.ow2.orchestra.services.handlers.impl.DeleteFinishedInstanceHandler;
import org.ow2.orchestra.util.Misc;

/**
 * generates a default environment for running orchestra with axis.
 *
 * @author Guillaume Porcher
 */
public class AxisEnvXmlGenerator extends DefaultEnvXMLGenerator {


  public AxisEnvXmlGenerator(final String hibernateRelativePath) {
    super(hibernateRelativePath);
    this.setPublisherType(AxisPublisher.class);
    this.setInvokerType(AxisInvoker.class);
    this.setFinishedInstanceHandlerType(DeleteFinishedInstanceHandler.class,
      ArchiveFinishedInstanceHandler.class);
    this.setUndeployedProcessHandlerType(ArchiveUndeployedProcessHandler.class);
  }

  /**
   * Prints the default environment on standard output.
   *
   * @param args
   * @throws IOException
   */
  public static void main(final String[] args) throws IOException {
    if (args.length == 0) {
      System.out.println(new AxisEnvXmlGenerator(null).createEnvironmentXml());
    } else if (args.length == 1) {
      Misc.write(new AxisEnvXmlGenerator(null).createEnvironmentXml(), new File(args[0]));
    } else if (args.length == 2) {
      Misc.write(new AxisEnvXmlGenerator(args[1]).createEnvironmentXml(), new File(args[0]));
    } else {
      throw new OrchestraRuntimeException("Invalid arguments");
    }
  }
}

==> orchestra-axis-4.1.0-sources.jar: org/ow2/orchestra/axis/AxisEnvXmlGenerator.java <==
package org.ow2.orchestra.axis;

import java.io.File;
import java.io.IOException;

import org.ow2.orchestra.env.DefaultEnvXMLGenerator;
import org.ow2.orchestra.facade.exception.OrchestraRuntimeException;
import org.ow2.orchestra.services.handlers.impl.ArchiveFinishedInstanceHandler;
import org.ow2.orchestra.services.handlers.impl.ArchiveUndeployedProcessHandler;
import org.ow2.orchestra.services.handlers.impl.DeleteFinishedInstanceHandler;
import org.ow2.orchestra.services.impl.SOAPInvoker;
import org.ow2.orchestra.util.Misc;

/**
 * generates a default environment for running orchestra with axis.
 *
 * @author Guillaume Porcher
 */
public class AxisEnvXmlGenerator extends DefaultEnvXMLGenerator {


  public AxisEnvXmlGenerator(final String hibernateRelativePath) {
    super(hibernateRelativePath);
    this.setPublisherType(AxisPublisher.class);
    this.setInvokerType(SOAPInvoker.class);
    this.setFinishedInstanceHandlerType(DeleteFinishedInstanceHandler.class,
      ArchiveFinishedInstanceHandler.class);
    this.setUndeployedProcessHandlerType(ArchiveUndeployedProcessHandler.class);
  }

  /**
   * Prints the default environment on standard output.
   *
   * @param args
   * @throws IOException
   */
  public static void main(final String[] args) throws IOException {
    if (args.length == 0) {
      System.out.println(new AxisEnvXmlGenerator(null).createEnvironmentXml());
    } else if (args.length == 1) {
      Misc.write(new AxisEnvXmlGenerator(null).createEnvironmentXml(), new File(args[0]));
    } else if (args.length == 2) {
      Misc.write(new AxisEnvXmlGenerator(args[1]).createEnvironmentXml(), new File(args[0]));
    } else {
      throw new OrchestraRuntimeException("Invalid arguments");
    }
  }
}
